@@ -2,15 +2,14 @@
 # Graph::Reader::HTK - perl module for reading an HTK lattice into a Graph
 #
 package Graph::Reader::HTK;
-
+$Graph::Reader::HTK::VERSION = '2.08';
+use 5.006;
 use strict;
 use warnings;
 
 use parent 'Graph::Reader';
 use Carp;
 
-our $VERSION = '2.06';
-
 my %node_attributes =
 (
   'WORD' => [ 'WORD', 'label' ],
@@ -199,34 +198,46 @@ Graph::Reader::HTK - read an HTK lattice in as an instance of Graph
 =head1 SYNOPSIS
 
   use Graph::Reader::HTK;
-  
+
   $reader = Graph::Reader::HTK->new;
   $graph = $reader->read_graph('mylattice.lat');
 
 =head1 DESCRIPTION
 
+This module can be used to read a directed graph in the
+L<HTK|http://htk.eng.cam.ac.uk> lattice
+format. It returns an instance of the L<Graph> class.
+
 =head1 SEE ALSO
 
 =over 4
 
-=item Graph
+=item L<Graph>
 
 Jarkko Hietaniemi's Graph class and others, used for representing
 and manipulating directed graphs. Available from CPAN.
 Also described / used in the chapter on directed graph algorithms
 in the B<Algorithms in Perl> book from O'Reilly.
 
-=item Graph::Reader
+=item L<Graph::Reader>
 
 The base-class for this module, which defines the public methods,
 and describes the ideas behind Graph reader and writer modules.
 
-=item Graph::Writer::HTK
+=item L<Graph::Writer::HTK>
 
 A class which will write a perl Graph out as an HTK lattice.
 
+=item L<HTK|http://htk.eng.cam.ac.uk>
+
+The Hidden Markov Model Toolkit.
+
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/Graph-ReadWrite>
+
 =head1 AUTHOR
 
 Neil Bowers E<lt>neil@bowers.comE<gt>
