@@ -2,12 +2,12 @@
 # Graph::Writer::Dot - write a directed graph out in Dot format
 #
 package Graph::Writer::Dot;
-
+$Graph::Writer::Dot::VERSION = '2.08';
+use 5.006;
 use strict;
 use warnings;
 
 use parent 'Graph::Writer';
-our $VERSION = '2.05';
 
 #-----------------------------------------------------------------------
 # List of valid dot attributes for the entire graph, per node,
@@ -165,10 +165,10 @@ Graph::Writer::Dot - write out directed graph in Dot format
 
   use Graph;
   use Graph::Writer::Dot;
-    
+
   $graph = Graph->new();
   # add edges and nodes to the graph
-    
+
   $writer = Graph::Writer::Dot->new();
   $writer->write_graph($graph, 'mygraph.dot');
 
@@ -203,12 +203,12 @@ or a filehandle for a previously opened file.
 
 =over 4
 
-=item http://www.graphviz.org/
+=item L<www.graphviz.org|http://www.graphviz.org/>
 
 The home page for the AT+T graphviz toolkit that
 includes the dot tool.
 
-=item Graph
+=item L<Graph>
 
 Jarkko Hietaniemi's modules for representing directed graphs,
 available from CPAN under modules/by-module/Graph/
@@ -218,12 +218,16 @@ available from CPAN under modules/by-module/Graph/
 The O'Reilly book which has a chapter on directed graphs,
 which is based around Jarkko's modules.
 
-=item Graph::Writer
+=item L<Graph::Writer>
 
 The base-class for Graph::Writer::Dot
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/Graph-ReadWrite>
+
 =head1 AUTHOR
 
 Neil Bowers E<lt>neil@bowers.comE<gt>
