@@ -2,7 +2,8 @@
 # Graph::Writer::HTK - perl module for writing a Graph as an HTK lattice
 #
 package Graph::Writer::HTK;
-
+$Graph::Writer::HTK::VERSION = '2.08';
+use 5.006;
 use strict;
 use warnings;
 
@@ -10,7 +11,6 @@ use warnings;
 #=======================================================================
 
 use parent 'Graph::Writer';
-our $VERSION = '2.06';
 
 my @graph_attributes = qw(base lmname lmscale wdpenalty);
 
@@ -121,34 +121,42 @@ Graph::Writer::HTK - write a perl Graph out as an HTK lattice file
 =head1 SYNOPSIS
 
   use Graph::Writer::HTK;
-  
+
   $writer = Graph::Reader::HTK->new();
   $reader->write_graph($graph, 'mylattice.lat');
 
 =head1 DESCRIPTION
 
+This module will write a directed graph to a file
+in the L<HTK|http://htk.eng.cam.ac.uk> lattice format.
+The graph must be an instance of the L<Graph> class.
+
 =head1 SEE ALSO
 
 =over 4
 
-=item Graph
+=item L<Graph>
 
 Jarkko Hietaniemi's Graph class and others, used for representing
 and manipulating directed graphs. Available from CPAN.
 Also described / used in the chapter on directed graph algorithms
 in the B<Algorithms in Perl> book from O'Reilly.
 
-=item Graph::Writer
+=item L<Graph::Writer>
 
 The base-class for this module, which defines the public methods,
 and describes the ideas behind Graph reader and writer modules.
 
-=item Graph::Reader::HTK
+=item L<Graph::Reader::HTK>
 
 A class which will read a perl Graph from an HTK lattice file.
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/Graph-ReadWrite>
+
 =head1 AUTHOR
 
 Neil Bowers E<lt>neil@bowers.comE<gt>
