@@ -2,12 +2,12 @@
 # Graph::Writer::VCG - write a directed graph out in VCG format
 #
 package Graph::Writer::VCG;
-
+$Graph::Writer::VCG::VERSION = '2.08';
+use 5.006;
 use strict;
 use warnings;
 
 use parent 'Graph::Writer';
-our $VERSION = '2.06';
 
 #-----------------------------------------------------------------------
 # Attribute type information
@@ -293,10 +293,10 @@ Graph::Writer::VCG - write out directed graph in VCG format
 
   use Graph;
   use Graph::Writer::VCG;
-  
+
   $graph = Graph->new();
   # add edges and nodes to the graph
-  
+
   $writer = Graph::Writer::VCG->new();
   $writer->write_graph($graph, 'mygraph.vcg');
 
@@ -358,7 +358,7 @@ So doesn't know about B<foldnode_defaults> and things like that.
 
 The home page for VCG.
 
-=item Graph
+=item L<Graph>
 
 Jarkko Hietaniemi's modules for representing directed graphs,
 available from CPAN under modules/by-module/Graph/
@@ -368,12 +368,16 @@ available from CPAN under modules/by-module/Graph/
 The O'Reilly book which has a chapter on directed graphs,
 which is based around Jarkko's modules.
 
-=item Graph::Writer
+=item L<Graph::Writer>
 
 The base-class for Graph::Writer::VCG
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/Graph-ReadWrite>
+
 =head1 AUTHOR
 
 Neil Bowers E<lt>neil@bowers.comE<gt>
