@@ -2,12 +2,12 @@
 # Graph::Writer::daVinci - write a directed graph out in daVinci format
 #
 package Graph::Writer::daVinci;
-
+$Graph::Writer::daVinci::VERSION = '2.08';
+use 5.006;
 use strict;
 use warnings;
 
 use parent 'Graph::Writer';
-our $VERSION = '2.07';
 
 #-----------------------------------------------------------------------
 # List of valid daVinci attributes for the entire graph, per node,
@@ -182,10 +182,10 @@ Graph::Writer::daVinci - write out directed graph in daVinci format
 
   use Graph;
   use Graph::Writer::daVinci;
-    
+
   $graph = Graph->new();
   # add edges and nodes to the graph
-    
+
   $writer = Graph::Writer::daVinci->new();
   $writer->write_graph($graph, 'mygraph.davinci');
 
@@ -239,6 +239,10 @@ The base-class for Graph::Writer::daVinci
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/Graph-ReadWrite>
+
 =head1 AUTHOR
 
 Neil Bowers E<lt>neil@bowers.comE<gt>
